# AuthlyX



### A simple AuthlyX (https://authly.cc/) api wrapper

How to use?


Install ``pip install AuthlyX``
And use!

Example: https://gitlab.com/authlyx/authlyx-py-example/-/raw/main/main.py?ref_type=heads

Made by nonepy :)